@@ -3,7 +3,7 @@ package MojoX::Session;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use base 'Mojo::Base';
 
@@ -121,6 +121,15 @@ sub data {
     $self->_is_flushed(0);
 }
 
+sub flash {
+    my $self = shift;
+    my ($key) = @_;
+
+    return unless $key;
+
+    return delete $self->data->{$key};
+}
+
 sub clear {
     my $self = shift;
     my ($key) = @_;
@@ -180,12 +189,6 @@ sub _generate_sid {
     $self->sid($sha1->hexdigest);
 }
 
-sub DESTROY {
-    my $self = shift;
-
-    $self->flush();
-}
-
 1;
 __END__
 
@@ -289,8 +292,6 @@ Flush actually writes to the store in these situations:
 - any value was changed (updates it)
 - session is expired (deletes it)
 
-Flush is also called on object destruction.
-
 =head2 C<sid>
 
     my $sid = $session->sid;
@@ -309,6 +310,16 @@ Returns session id.
 
 Get and set values to the session.
 
+=head2 C<flash>
+
+    my $foo = $session->data('foo');
+    $session->data('foo' => 'bar');
+    $session->flash('foo'); # get foo and delete it from data
+    $session->data('foo');  # undef
+
+Get value and delete it from data. Usefull when you want to store error messages
+etc.
+
 =head2 C<clear>
 
     $session->clear('bar');
@@ -331,8 +342,6 @@ Get/set session expire time.
     $session->flush;
 
 Force session to expire. Call flush if you want to remove it from the store.
-Flush will be called also on object destruction and will automatically delete
-expired session from the store.
 
 =head2 C<is_expired>
 
